==> openshift-model-config-6.8.0-sources.jar: io/fabric8/openshift/api/model/config/v1/VSpherePlatformNodeNetworkingFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VSpherePlatformNodeNetworkingFluent<A extends VSpherePlatformNodeNetworkingFluent<A>> extends BaseFluent<A>{
  public VSpherePlatformNodeNetworkingFluent() {
  }
  public VSpherePlatformNodeNetworkingFluent(VSpherePlatformNodeNetworking instance) {
    instance = (instance != null ? instance : new VSpherePlatformNodeNetworking());

    if (instance != null) {
      this.withExternal(instance.getExternal());
      this.withInternal(instance.getInternal());
      this.withExternal(instance.getExternal());
      this.withInternal(instance.getInternal());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private VSpherePlatformNodeNetworkingSpecBuilder external;
  private VSpherePlatformNodeNetworkingSpecBuilder internal;
  private Map<String,Object> additionalProperties;
  public VSpherePlatformNodeNetworkingSpec buildExternal() {
    return this.external!=null ?this.external.build():null;
  }
  public A withExternal(VSpherePlatformNodeNetworkingSpec external) {
    _visitables.get("external").remove(this.external);
    if (external!=null){ this.external= new VSpherePlatformNodeNetworkingSpecBuilder(external); _visitables.get("external").add(this.external);} else { this.external = null; _visitables.get("external").remove(this.external); } return (A) this;
  }
  public boolean hasExternal() {
    return this.external != null;
  }
  public ExternalNested<A> withNewExternal() {
    return new ExternalNested(null);
  }
  public ExternalNested<A> withNewExternalLike(VSpherePlatformNodeNetworkingSpec item) {
    return new ExternalNested(item);
  }
  public ExternalNested<A> editExternal() {
    return withNewExternalLike(java.util.Optional.ofNullable(buildExternal()).orElse(null));
  }
  public ExternalNested<A> editOrNewExternal() {
    return withNewExternalLike(java.util.Optional.ofNullable(buildExternal()).orElse(new VSpherePlatformNodeNetworkingSpecBuilder().build()));
  }
  public ExternalNested<A> editOrNewExternalLike(VSpherePlatformNodeNetworkingSpec item) {
    return withNewExternalLike(java.util.Optional.ofNullable(buildExternal()).orElse(item));
  }
  public VSpherePlatformNodeNetworkingSpec buildInternal() {
    return this.internal!=null ?this.internal.build():null;
  }
  public A withInternal(VSpherePlatformNodeNetworkingSpec internal) {
    _visitables.get("internal").remove(this.internal);
    if (internal!=null){ this.internal= new VSpherePlatformNodeNetworkingSpecBuilder(internal); _visitables.get("internal").add(this.internal);} else { this.internal = null; _visitables.get("internal").remove(this.internal); } return (A) this;
  }
  public boolean hasInternal() {
    return this.internal != null;
  }
  public InternalNested<A> withNewInternal() {
    return new InternalNested(null);
  }
  public InternalNested<A> withNewInternalLike(VSpherePlatformNodeNetworkingSpec item) {
    return new InternalNested(item);
  }
  public InternalNested<A> editInternal() {
    return withNewInternalLike(java.util.Optional.ofNullable(buildInternal()).orElse(null));
  }
  public InternalNested<A> editOrNewInternal() {
    return withNewInternalLike(java.util.Optional.ofNullable(buildInternal()).orElse(new VSpherePlatformNodeNetworkingSpecBuilder().build()));
  }
  public InternalNested<A> editOrNewInternalLike(VSpherePlatformNodeNetworkingSpec item) {
    return withNewInternalLike(java.util.Optional.ofNullable(buildInternal()).orElse(item));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VSpherePlatformNodeNetworkingFluent that = (VSpherePlatformNodeNetworkingFluent) o;
    if (!java.util.Objects.equals(external, that.external)) return false;

    if (!java.util.Objects.equals(internal, that.internal)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(external,  internal,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (external != null) { sb.append("external:"); sb.append(external + ","); }
    if (internal != null) { sb.append("internal:"); sb.append(internal + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ExternalNested<N> extends VSpherePlatformNodeNetworkingSpecFluent<ExternalNested<N>> implements Nested<N>{
    ExternalNested(VSpherePlatformNodeNetworkingSpec item) {
      this.builder = new VSpherePlatformNodeNetworkingSpecBuilder(this, item);
    }
    VSpherePlatformNodeNetworkingSpecBuilder builder;
    public N and() {
      return (N) VSpherePlatformNodeNetworkingFluent.this.withExternal(builder.build());
    }
    public N endExternal() {
      return and();
    }
    
  }
  public class InternalNested<N> extends VSpherePlatformNodeNetworkingSpecFluent<InternalNested<N>> implements Nested<N>{
    InternalNested(VSpherePlatformNodeNetworkingSpec item) {
      this.builder = new VSpherePlatformNodeNetworkingSpecBuilder(this, item);
    }
    VSpherePlatformNodeNetworkingSpecBuilder builder;
    public N and() {
      return (N) VSpherePlatformNodeNetworkingFluent.this.withInternal(builder.build());
    }
    public N endInternal() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.9.0-sources.jar: io/fabric8/openshift/api/model/config/v1/VSpherePlatformNodeNetworkingFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class VSpherePlatformNodeNetworkingFluent<A extends VSpherePlatformNodeNetworkingFluent<A>> extends BaseFluent<A>{
  public VSpherePlatformNodeNetworkingFluent() {
  }
  
  public VSpherePlatformNodeNetworkingFluent(VSpherePlatformNodeNetworking instance) {
    this.copyInstance(instance);
  }
  private VSpherePlatformNodeNetworkingSpecBuilder external;
  private VSpherePlatformNodeNetworkingSpecBuilder internal;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(VSpherePlatformNodeNetworking instance) {
    instance = (instance != null ? instance : new VSpherePlatformNodeNetworking());
  
    if (instance != null) {
        this.withExternal(instance.getExternal());
        this.withInternal(instance.getInternal());
        this.withExternal(instance.getExternal());
        this.withInternal(instance.getInternal());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public VSpherePlatformNodeNetworkingSpec buildExternal() {
    return this.external!=null ?this.external.build():null;
  }
  
  public A withExternal(VSpherePlatformNodeNetworkingSpec external) {
    _visitables.get("external").remove(this.external);
    if (external!=null){ this.external= new VSpherePlatformNodeNetworkingSpecBuilder(external); _visitables.get("external").add(this.external);} else { this.external = null; _visitables.get("external").remove(this.external); } return (A) this;
  }
  
  public boolean hasExternal() {
    return this.external != null;
  }
  
  public ExternalNested<A> withNewExternal() {
    return new ExternalNested(null);
  }
  
  public ExternalNested<A> withNewExternalLike(VSpherePlatformNodeNetworkingSpec item) {
    return new ExternalNested(item);
  }
  
  public ExternalNested<A> editExternal() {
    return withNewExternalLike(java.util.Optional.ofNullable(buildExternal()).orElse(null));
  }
  
  public ExternalNested<A> editOrNewExternal() {
    return withNewExternalLike(java.util.Optional.ofNullable(buildExternal()).orElse(new VSpherePlatformNodeNetworkingSpecBuilder().build()));
  }
  
  public ExternalNested<A> editOrNewExternalLike(VSpherePlatformNodeNetworkingSpec item) {
    return withNewExternalLike(java.util.Optional.ofNullable(buildExternal()).orElse(item));
  }
  
  public VSpherePlatformNodeNetworkingSpec buildInternal() {
    return this.internal!=null ?this.internal.build():null;
  }
  
  public A withInternal(VSpherePlatformNodeNetworkingSpec internal) {
    _visitables.get("internal").remove(this.internal);
    if (internal!=null){ this.internal= new VSpherePlatformNodeNetworkingSpecBuilder(internal); _visitables.get("internal").add(this.internal);} else { this.internal = null; _visitables.get("internal").remove(this.internal); } return (A) this;
  }
  
  public boolean hasInternal() {
    return this.internal != null;
  }
  
  public InternalNested<A> withNewInternal() {
    return new InternalNested(null);
  }
  
  public InternalNested<A> withNewInternalLike(VSpherePlatformNodeNetworkingSpec item) {
    return new InternalNested(item);
  }
  
  public InternalNested<A> editInternal() {
    return withNewInternalLike(java.util.Optional.ofNullable(buildInternal()).orElse(null));
  }
  
  public InternalNested<A> editOrNewInternal() {
    return withNewInternalLike(java.util.Optional.ofNullable(buildInternal()).orElse(new VSpherePlatformNodeNetworkingSpecBuilder().build()));
  }
  
  public InternalNested<A> editOrNewInternalLike(VSpherePlatformNodeNetworkingSpec item) {
    return withNewInternalLike(java.util.Optional.ofNullable(buildInternal()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VSpherePlatformNodeNetworkingFluent that = (VSpherePlatformNodeNetworkingFluent) o;
    if (!java.util.Objects.equals(external, that.external)) return false;
  
    if (!java.util.Objects.equals(internal, that.internal)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(external,  internal,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (external != null) { sb.append("external:"); sb.append(external + ","); }
    if (internal != null) { sb.append("internal:"); sb.append(internal + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ExternalNested<N> extends VSpherePlatformNodeNetworkingSpecFluent<ExternalNested<N>> implements Nested<N>{
    ExternalNested(VSpherePlatformNodeNetworkingSpec item) {
      this.builder = new VSpherePlatformNodeNetworkingSpecBuilder(this, item);
    }
    VSpherePlatformNodeNetworkingSpecBuilder builder;
    
    public N and() {
      return (N) VSpherePlatformNodeNetworkingFluent.this.withExternal(builder.build());
    }
    
    public N endExternal() {
      return and();
    }
    
  
  }
  public class InternalNested<N> extends VSpherePlatformNodeNetworkingSpecFluent<InternalNested<N>> implements Nested<N>{
    InternalNested(VSpherePlatformNodeNetworkingSpec item) {
      this.builder = new VSpherePlatformNodeNetworkingSpecBuilder(this, item);
    }
    VSpherePlatformNodeNetworkingSpecBuilder builder;
    
    public N and() {
      return (N) VSpherePlatformNodeNetworkingFluent.this.withInternal(builder.build());
    }
    
    public N endInternal() {
      return and();
    }
    
  
  }

}
